==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebExpansionPanelDescriptionMetadata_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebExpansionPanelDescription } from "./WebExpansionPanelDescription";
import { WebExpansionPanelComponentEventArgsDescription } from "./WebExpansionPanelComponentEventArgsDescription";
/**
 * @hidden
 */
var WebExpansionPanelDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebExpansionPanelDescriptionMetadata, _super);
    function WebExpansionPanelDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebExpansionPanelDescriptionMetadata.b = function (a) {
        if (WebExpansionPanelDescriptionMetadata.a == null) {
            WebExpansionPanelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebExpansionPanelDescriptionMetadata.c(WebExpansionPanelDescriptionMetadata.a);
        }
        if (a.g(WebExpansionPanelDescriptionMetadata.a)) {
            return;
        }
        a.s(WebExpansionPanelDescriptionMetadata.a);
        WebExpansionPanelComponentEventArgsDescriptionMetadata.d(a);
    };
    WebExpansionPanelDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ExpansionPanel");
        a.item("Open", "Boolean");
        a.item("Disabled", "Boolean");
        a.item("IndicatorPosition", "ExportedType:string:ExpansionPanelIndicatorPosition");
        a.item("IndicatorPosition@names", "Start;End;None");
        a.item("OpeningRef", "EventRef::opening");
        a.item("OpenedRef", "EventRef::opened");
        a.item("ClosingRef", "EventRef::closing");
        a.item("ClosedRef", "EventRef::closed");
    };
    WebExpansionPanelDescriptionMetadata.d = function (a) {
        WebExpansionPanelDescriptionMetadata.b(a);
        a.u("WebExpansionPanel", function () { return new WebExpansionPanelDescription(); });
        a.t("WebExpansionPanel", WebExpansionPanelDescriptionMetadata.a);
    };
    WebExpansionPanelDescriptionMetadata.$t = markType(WebExpansionPanelDescriptionMetadata, 'WebExpansionPanelDescriptionMetadata');
    WebExpansionPanelDescriptionMetadata.a = null;
    return WebExpansionPanelDescriptionMetadata;
}(Base));
export { WebExpansionPanelDescriptionMetadata };
/**
 * @hidden
 */
var WebExpansionPanelComponentEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebExpansionPanelComponentEventArgsDescriptionMetadata, _super);
    function WebExpansionPanelComponentEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebExpansionPanelComponentEventArgsDescriptionMetadata.b = function (a) {
        if (WebExpansionPanelComponentEventArgsDescriptionMetadata.a == null) {
            WebExpansionPanelComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebExpansionPanelComponentEventArgsDescriptionMetadata.c(WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
        }
        if (a.g(WebExpansionPanelComponentEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
        WebExpansionPanelDescriptionMetadata.d(a);
    };
    WebExpansionPanelComponentEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ExpansionPanelComponentEventArgs");
        a.item("Detail", "ExportedType:WebExpansionPanel");
    };
    WebExpansionPanelComponentEventArgsDescriptionMetadata.d = function (a) {
        WebExpansionPanelComponentEventArgsDescriptionMetadata.b(a);
        a.u("WebExpansionPanelComponentEventArgs", function () { return new WebExpansionPanelComponentEventArgsDescription(); });
        a.t("WebExpansionPanelComponentEventArgs", WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
    };
    WebExpansionPanelComponentEventArgsDescriptionMetadata.$t = markType(WebExpansionPanelComponentEventArgsDescriptionMetadata, 'WebExpansionPanelComponentEventArgsDescriptionMetadata');
    WebExpansionPanelComponentEventArgsDescriptionMetadata.a = null;
    return WebExpansionPanelComponentEventArgsDescriptionMetadata;
}(Base));
export { WebExpansionPanelComponentEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebExpansionPanelDescriptionMetadata_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebExpansionPanelDescription } from "./WebExpansionPanelDescription";
import { WebExpansionPanelComponentEventArgsDescription } from "./WebExpansionPanelComponentEventArgsDescription";
/**
 * @hidden
 */
var WebExpansionPanelDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebExpansionPanelDescriptionMetadata, _super);
    function WebExpansionPanelDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebExpansionPanelDescriptionMetadata.b = function (a) {
        if (WebExpansionPanelDescriptionMetadata.a == null) {
            WebExpansionPanelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebExpansionPanelDescriptionMetadata.c(WebExpansionPanelDescriptionMetadata.a);
        }
        if (a.j(WebExpansionPanelDescriptionMetadata.a)) {
            return;
        }
        a.y(WebExpansionPanelDescriptionMetadata.a);
        WebExpansionPanelComponentEventArgsDescriptionMetadata.d(a);
    };
    WebExpansionPanelDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ExpansionPanel");
        a.item("__tagNameWC", "String:igc-expansion-panel");
        a.item("Open", "Boolean");
        a.item("Disabled", "Boolean");
        a.item("IndicatorPosition", "ExportedType:string:ExpansionPanelIndicatorPosition");
        a.item("IndicatorPosition@names", "Start;End;None");
        a.item("OpeningRef", "EventRef::opening");
        a.item("OpenedRef", "EventRef::opened");
        a.item("ClosingRef", "EventRef::closing");
        a.item("ClosedRef", "EventRef::closed");
    };
    WebExpansionPanelDescriptionMetadata.d = function (a) {
        WebExpansionPanelDescriptionMetadata.b(a);
        a.aa("WebExpansionPanel", function () { return new WebExpansionPanelDescription(); });
        a.z("WebExpansionPanel", WebExpansionPanelDescriptionMetadata.a);
    };
    WebExpansionPanelDescriptionMetadata.$t = markType(WebExpansionPanelDescriptionMetadata, 'WebExpansionPanelDescriptionMetadata');
    WebExpansionPanelDescriptionMetadata.a = null;
    return WebExpansionPanelDescriptionMetadata;
}(Base));
export { WebExpansionPanelDescriptionMetadata };
/**
 * @hidden
 */
var WebExpansionPanelComponentEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebExpansionPanelComponentEventArgsDescriptionMetadata, _super);
    function WebExpansionPanelComponentEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebExpansionPanelComponentEventArgsDescriptionMetadata.b = function (a) {
        if (WebExpansionPanelComponentEventArgsDescriptionMetadata.a == null) {
            WebExpansionPanelComponentEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebExpansionPanelComponentEventArgsDescriptionMetadata.c(WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebExpansionPanelComponentEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
        WebExpansionPanelDescriptionMetadata.d(a);
    };
    WebExpansionPanelComponentEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ExpansionPanelComponentEventArgs");
        a.item("Detail", "ExportedType:WebExpansionPanel");
    };
    WebExpansionPanelComponentEventArgsDescriptionMetadata.d = function (a) {
        WebExpansionPanelComponentEventArgsDescriptionMetadata.b(a);
        a.aa("WebExpansionPanelComponentEventArgs", function () { return new WebExpansionPanelComponentEventArgsDescription(); });
        a.z("WebExpansionPanelComponentEventArgs", WebExpansionPanelComponentEventArgsDescriptionMetadata.a);
    };
    WebExpansionPanelComponentEventArgsDescriptionMetadata.$t = markType(WebExpansionPanelComponentEventArgsDescriptionMetadata, 'WebExpansionPanelComponentEventArgsDescriptionMetadata');
    WebExpansionPanelComponentEventArgsDescriptionMetadata.a = null;
    return WebExpansionPanelComponentEventArgsDescriptionMetadata;
}(Base));
export { WebExpansionPanelComponentEventArgsDescriptionMetadata };
